| Title: | Shiny App for Analysing Boreal Caribou Surival, Recruitment and Lambda |
|---|---|
| Description: | Use Bayesian methods to calculate survival, recruitment and lambda as well as confidence intervals. |
| Authors: | Pearson Ayla [aut, cre] (ORCID: <https://orcid.org/0000-0001-7388-1222>), Joe Thorley [ctb] (ORCID: <https://orcid.org/0000-0002-7683-4592>), Seb Dalgarno [ctb] (ORCID: <https://orcid.org/0000-0002-3658-4517>), Province of Alberta [cph] |
| Maintainer: | Pearson Ayla <[email protected]> |
| License: | Apache License (>= 2) |
| Version: | 0.3.1 |
| Built: | 2026-06-05 19:51:58 UTC |
| Source: | https://github.com/poissonconsulting/bboushiny |
Launches the application from your R console
run_bbou_app()run_bbou_app()
## Not run: run_bbou_app() ## End(Not run)## Not run: run_bbou_app() ## End(Not run)